# live_indonesia_earthquake
This package gets the latest earthquake in Indonesia from the official government agency

## How does it work?
This package scrapes live Indonesian earthquake data from Indonesian Agency for Meteorological, Climatological and Geophysics ([BMKG](https://bmkg.go.id)).
It uses BeautifulSoup4 and Requests packages to produce outputs in the form of JSON. The generated outputs is readily available for web or mobile applications.

## How to use it?
To install the package, copy the pip installation of the latest version and paste it on your terminal. After installing, import the package using "import live_Indonesia_earthquake".

"""

import live_Indonesia_earthquake

if __name__ == '__main__':
    print('Live Earthquake Detection App')
    result = live_Indonesia_earthquake.data_extraction()
    live_Indonesia_earthquake.show_data(result)

"""

